import IsBatchDelete from '@/components/BatchOperation/isBatchDelete';
import IsEnableBox from '@/components/DictionaryBox/isEnable';
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import {
  deleteProjectDeleteProject,
  deleteProjectDeleteProjectByIds,
  postProjectGetProjectList,
} from '@/services/project/Project';
import { PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { PageContainer, ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess, useIntl } from '@umijs/max';
import { Button, message } from 'antd';
import React, { useRef, useState } from 'react';
import { proTableCommonOptions, proTablePaginationOptions } from '../../../../config/defaultTable';
import { ColumnDrawer } from './components/ColumnDrawer';
// import MyCreateForm from './components/MyCreateForm';
import CreateForm from './components/CreateForm';
import UpdateForm from './components/UpdateForm';
const ProjectList: React.FC = () => {
  /**
   * @en-US Pop-up window of new window
   * @zh-CN 新建窗口的弹窗
   *  */
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  const [showDetail, setShowDetail] = useState<boolean>(false);
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  const access = useAccess();
  const intl = useIntl();
  const actionRef = useRef<ActionType>();
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  const [currentRow, setCurrentRow] = useState<API.Project>();
  const [selectedRowsState, setSelectedRows] = useState<API.Project[]>([]);

  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setUpdateModalOpen(true);
    }
  };
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };
  const handleColumnDrawer = () => {
    if (showDetail) {
      setShowDetail(false);
      setCurrentRow(undefined);
    } else {
      setShowDetail(true);
    }
  };
  const handleDestroy = async (selectedRow: API.Project) => {
    deleteProjectDeleteProject({ id: selectedRow.id })
      .then(() => {
        message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        actionRef.current?.reload();
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  };

  const columns: ProColumns<API.Project>[] = [
    {
      title: <FormattedMessage id="contact.contact.table.list.name" defaultMessage="$$$" />,
      dataIndex: 'name',
      sorter: true,
      // render: (dom, entity) => {
      //   return (
      //     <a
      //       onClick={() => {
      //         setCurrentRow(entity);
      //         setShowDetail(true);
      //       }}
      //     >
      //       {dom}
      //     </a>
      //   );
      // },
      key: 'fixedName',
      fixed: 'left',
    },
    {
      title: <FormattedMessage id="contact.contact.table.list.phone" defaultMessage="$$$" />,
      dataIndex: 'code',
      // hideInSearch: true,
    },

    {
      title: <FormattedMessage id="contact.contact.table.list.mail" defaultMessage="$$$" />,
      dataIndex: 'info',
      hideInSearch: true,
    },
    {
      title: <FormattedMessage id="contact.contact.table.list.WeChatID" defaultMessage="$$$" />,
      dataIndex: 'info',
      hideInSearch: true,
    },

    // {
    //   title: <FormattedMessage id="contact.contact.table.list.inferConfig" defaultMessage="$$$" />,
    //   dataIndex: 'inferConfig',
    //   hideInSearch: true,
    //   hideInTable: true,
    //   hideInDescriptions: true,
    // },

    // {
    //   title: <FormattedMessage id="project.project.table.list.isEnable" defaultMessage="$$$" />,
    //   dataIndex: 'isEnable',
    //   filters: true,
    //   onFilter: true,
    //   hideInSearch: true,
    //   valueType: 'switch',
    //   render: (_text, item) => {
    //     return (
    //       <>
    //         <IsEnableBox isEnable={!!item.isEnable}></IsEnableBox>
    //       </>
    //     );
    //   },
    // },
    // {
    //   title: <FormattedMessage id="project.project.table.list.remark" defaultMessage="$$$" />,
    //   dataIndex: 'remark',
    //   hideInSearch: true,
    // },

    {
      title: <FormattedMessage id="contact.contact.table.list.createTime" defaultMessage="$$$" />,
      dataIndex: 'createTime',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    // {
    //   title: <FormattedMessage id="project.project.table.list.updateTime" defaultMessage="$$$" />,
    //   dataIndex: 'updateTime',
    //   sorter: true,
    //   hideInSearch: true,
    //   valueType: 'dateTime',
    // },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
              key: 'update',
              renderDom: (
                <Button
                  key="update"
                  type="link"
                  size="small"
                  onClick={() => {
                    setUpdateModalOpen(true);
                    setCurrentRow(record);
                  }}
                >
                  <FormattedMessage id="contact.contact.table.list.editor" defaultMessage="editor" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <PageContainer>
      <ProTable<API.Project>
        headerTitle={intl.formatMessage({
          id: 'pages.searchTable.title',
          defaultMessage: '$$$',
        })}
        scroll={{ y: proTableCommonOptions.commscrollY, x: proTableCommonOptions.commscrollX }}
        options={{ fullScreen: true, setting: true, density: true, reload: true }}
        actionRef={actionRef}
        rowKey="key"
        search={{
          labelWidth: proTableCommonOptions.searchLabelWidth,
        }}
        onDataSourceChange={() => {}}
        pagination={{
          ...proTablePaginationOptions,
          pageSize: currentPageSize,
          onChange: (page, pageSize) => setCurrentPageSize(pageSize),
        }}
        columnsState={{
          persistenceKey: 'project_list',
          persistenceType: 'localStorage',
        }}
        tableAlertOptionRender={() => {
          return (
            <>
              {selectedRowsState?.length > 0 && (
                <IsBatchDelete
                  deleteApi={() => {
                    // TODO 需要；联调删除接口
                    deleteProjectDeleteProjectByIds({
                      ids: selectedRowsState.map((v: API.Project) => {
                        return v.id as number;
                      }),
                    }).then(() => {
                      actionRef.current?.reloadAndRest?.();
                    });
                  }}
                />
              )}
            </>
          );
        }}
        toolBarRender={() => [
          <Access
            accessible={access.canUpdate(history.location.pathname)}
            key={`${history.location.pathname}-add`}
          >
            <Button
              type="primary"
              key="primary"
              onClick={() => {
                setCreateModalOpen(true);
              }}
            >
              <PlusOutlined /> <FormattedMessage id="pages.searchTable.new" defaultMessage="New" />
            </Button>
          </Access>,
        ]}
        request={async (params = {}, sort) => {
          const { current, ...rest } = params;
          const reqParams = {
            page: current,
            desc: false,
            orderKey: '',
            ...rest,
          };
          if (sort && Object.keys(sort).length) {
            reqParams.orderKey = Object.keys(sort)[0];
            let sort_select = sort[reqParams.orderKey];
            reqParams.desc = sort_select === 'descend';
          }
          let resp = await postProjectGetProjectList({ ...reqParams });
          return {
            data: resp.data.list.map((v: API.Project) => {
              return { ...v, key: v.id };
            }),
            success: resp.success,
            total: resp.data.total,
            current: resp.data.page,
            pageSize: resp.data.pageSize,
          };
        }}
        columns={columns}
        // rowSelection={{
        //   onChange: (_, selectedRows) => {
        //     setSelectedRows(selectedRows);
        //   },
        // }}
      />
      <CreateForm
        createModalOpen={createModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={actionRef.current?.reload}
      />
      <UpdateForm
        updateModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleUpdateModal}
        reload={actionRef.current?.reload}
      />

      <ColumnDrawer
        handleDrawer={handleColumnDrawer}
        isShowDetail={showDetail}
        columns={columns}
        currentRow={currentRow}
      />
    </PageContainer>
  );
};

export default ProjectList;
