import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import {
  deleteDeviceGroupDeleteDeviceGroup,
  deleteDeviceGroupDeleteDeviceGroupByIds,
  postDeviceGroupGetDeviceGroupList,
} from '@/services/device/DeviceGroup';
import { PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { FooterToolbar, PageContainer, ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess, useIntl } from '@umijs/max';
import { Button, message } from 'antd';
import React, { useRef, useState } from 'react';
import { ColumnDrawer } from './components/ColumnDrawer';
import CreateForm from './components/CreateForm';
import UpdateForm from './components/UpdateForm';
import IsBatchDelete from '@/components/BatchOperation/isBatchDelete';
import { proTableCommonOptions, proTablePaginationOptions } from '../../../../config/defaultTable';

const DeviceGroupList: React.FC = () => {
  /**
   * @en-US Pop-up window of new window
   * @zh-CN 新建窗口的弹窗
   *  */
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  const [showDetail, setShowDetail] = useState<boolean>(false);
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  const access = useAccess();
  const intl = useIntl();
  const actionRef = useRef<ActionType>();
    //  动态设置每页数量
    const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  const [currentRow, setCurrentRow] = useState<API.DeviceGroup>();
  const [selectedRowsState, setSelectedRows] = useState<API.DeviceGroup[]>([]);

  // const handle_parent_fk_id = (id: any)=>{
  //       if (parent_fk_id_open) {
  //           set_parent_fk_id(undefined);
  //           set_parent_fk_id_open(false)
  //       }else {
  //         postDeviceGroupGetDeviceGroupById({id: id}).then((resp)=>{
  //         set_parent_fk_id(resp.data.deviceGroup)
  //         set_parent_fk_id_open(true)
  //       })
  //       }
  //     }
  // const handle_parent_fk_id_column_open = ()=>{
  //   if (parent_fk_id_column_open) {
  //       set_parent_fk_id_column_open(false)
  //   }else {
  //     postDeviceGroupGetDeviceGroupNames({ids: parentFkIdIds}).then((resp)=>{
  //       let a: any = {}
  //       resp.data.list.forEach((v: any)=>{
  //         if (v.id) {
  //           a[v.id] = v.name
  //         }
  //       })
  //       setParentFkIdMap(a)
  //     })
  //     set_parent_fk_id_column_open(true)
  //   }
  // }

  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setUpdateModalOpen(true);
    }
  };
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };
  const handleColumnDrawer = () => {
    if (showDetail) {
      setShowDetail(false);
      setCurrentRow(undefined);
    } else {
      setShowDetail(true);
    }
  };
  const handleDestroy = async (selectedRow: API.DeviceGroup) => {
    deleteDeviceGroupDeleteDeviceGroup({ id: selectedRow.id })
      .then(() => {
        message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        actionRef.current?.reload();
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  };

  const columns: ProColumns<API.DeviceGroup>[] = [
    // TODO 确认是否需要和一级内容对齐
    {
      title: <span style={{paddingLeft: 0}}><FormattedMessage id="device.device_group.table.list.name" defaultMessage="id" /></span>,
      dataIndex: 'name',
      sorter: true,
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
      key: 'fixedName',
      fixed: 'left',
    },
    {
      title: <FormattedMessage id="device.device_group.table.list.code" defaultMessage="$$$" />,
      dataIndex: 'code',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="device.device_group.table.list.address" defaultMessage="$$$" />,
      dataIndex: 'address',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="device.device_group.table.list.telephone" defaultMessage="$$$" />
      ),
      dataIndex: 'telephone',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="device.device_group.table.list.lon" defaultMessage="$$$" />,
      dataIndex: 'lon',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="device.device_group.table.list.lat" defaultMessage="$$$" />,
      dataIndex: 'lat',
      hideInSearch: true,
    },
    {
      title: (
        <FormattedMessage id="device.device_group.table.list.managerName" defaultMessage="$$$" />
      ),
      dataIndex: 'managerName',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="device.device_group.table.list.managerPhone" defaultMessage="$$$" />
      ),
      dataIndex: 'managerPhone',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="device.device_group.table.list.isEnable" defaultMessage="$$$" />,
      dataIndex: 'isEnable',
      filters: true,
      onFilter: true,
      hideInSearch: true,
      valueType: 'switch',
    },

    //
    // {
    //     title: (<FormattedMessage
    //         id="device.device_group.table.list.parentFkId"
    //         defaultMessage="$$$"/>),
    //     dataIndex: "parentFkId",
    //     hideInSearch: false,
    //     render: (text, record) => {
    //             if (parent_fk_id_column_open) {
    //                 return ( <a onClick={()=>{handle_parent_fk_id(record.parentFkId)}}>{record?.parentFkId ? parentFkIdMap[record.parentFkId] : undefined}</a>)
    //             } else {
    //                 return (<a onClick={()=>{handle_parent_fk_id(record.parentFkId)}}>{record.parentFkId}</a>)
    //             }
    //     },
    //     renderFormItem: () => {
    //         return (
    //           // value 和 onchange 会通过 form 自动注入。
    //           <ProFormSelect
    //             placeholder={`${intl.formatMessage({id: 'common.please_select', defaultMessage: '$$$' })}`}
    //             required={false} showSearch debounceTime={1000}
    //             request={async (keyWord)=>{
    //               const resp = await postDeviceGroupGetDeviceGroupFkSelect({keyword: keyWord?.keyWords || ''})
    //               return resp.data.list.map((v: any)=>{
    //                 return {
    //                   label: v.name,
    //                   value: v.id
    //                 }
    //               })
    //             }}
    //           />
    //         );
    //   },
    // },

    {
      title: <FormattedMessage id="device.device_group.table.list.remark" defaultMessage="$$$" />,
      dataIndex: 'remark',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="device.device_group.table.list.createTime" defaultMessage="$$$" />
      ),
      dataIndex: 'createTime',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: (
        <FormattedMessage id="device.device_group.table.list.updateTime" defaultMessage="$$$" />
      ),
      dataIndex: 'updateTime',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
              key: 'create',
              renderDom: (
                <Button
                  key="create"
                  type="link"
                  size="small"
                  onClick={() => {
                    setCreateModalOpen(true);
                    setCurrentRow(record);
                    // setShowDetail(true);
                  }}
                >
                  <FormattedMessage id="common.create_son" defaultMessage="Create" />
                </Button>
              ),
            },
            {
              key: 'update',
              renderDom: (
                <Button
                  key="update"
                  type="link"
                  size="small"
                  onClick={() => {
                    setUpdateModalOpen(true);
                    setCurrentRow(record);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.update" defaultMessage="Update" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <PageContainer>
      <ProTable<API.DeviceGroup>
        headerTitle={intl.formatMessage({
          id: 'pages.searchTable.title',
          defaultMessage: '$$$',
        })}
        options={{ fullScreen: true, setting: true, density: true, reload: true }}
        actionRef={actionRef}
        rowKey="key"
        scroll={{ y: proTableCommonOptions.commscrollY, x: 1800}}
        search={{
          labelWidth: proTableCommonOptions.searchLabelWidth,
        }}
        pagination={{
          ...proTablePaginationOptions,
          pageSize: currentPageSize,
          onChange: (page, pageSize) => setCurrentPageSize(pageSize),
        }}
        columnsState={{
          persistenceKey: 'device_group_list',
          persistenceType: 'localStorage',
        }}
        tableAlertOptionRender={() => {
          return (
            <>
              {selectedRowsState?.length > 0 && (
                <IsBatchDelete
                  deleteApi={() => {
                    // TODO 需联调批量删除接口
                    deleteDeviceGroupDeleteDeviceGroupByIds({
                      ids: selectedRowsState.map((v: API.DeviceGroup) => {
                        return v.id as number;
                      }),
                    }).then(() => {
                      actionRef.current?.reloadAndRest?.();
                    });
                  }}
                />
              )}
            </>
          );
        }}
        toolBarRender={() => [
          <Access
            accessible={access.canUpdate(history.location.pathname)}
            key={`${history.location.pathname}-add`}
          >
            <Button
              type="primary"
              key="primary"
              onClick={() => {
                setCurrentRow(undefined);
                setCreateModalOpen(true);
              }}
            >
              <PlusOutlined />{' '}
              <FormattedMessage id="device.device_group.table.list.treeAdd" defaultMessage="New" />
            </Button>
          </Access>,
        ]}
        request={async (params = {}, sort) => {
          const { current, ...rest } = params;
          const reqParams = {
            page: current,
            desc: false,
            orderKey: '',
            ...rest,
          };
          if (sort && Object.keys(sort).length) {
            reqParams.orderKey = Object.keys(sort)[0];
            let sort_select = sort[reqParams.orderKey];
            reqParams.desc = sort_select === 'descend';
          }
          let resp = await postDeviceGroupGetDeviceGroupList({ ...reqParams });
          return {
            data: resp.data.list.map((v: API.DeviceGroup) => {
              return { ...v, key: v.id };
            }),
            success: resp.success,
            total: resp.data.total,
            current: resp.data.page,
            pageSize: resp.data.pageSize,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
          checkStrictly: false
        }}
      />
      <CreateForm
        createModalOpen={createModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={actionRef.current?.reload}
      />
      <UpdateForm
        updateModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleUpdateModal}
        reload={actionRef.current?.reload}
      />

      <ColumnDrawer
        handleDrawer={handleColumnDrawer}
        isShowDetail={showDetail}
        columns={columns}
        currentRow={currentRow}
      />
    </PageContainer>
  );
};

export default DeviceGroupList;
