/*
 * @Author: zhoux zhouxia@supervision.ltd
 * @Date: 2023-11-01 13:56:33
 * @LastEditors: zhoux zhouxia@supervision.ltd
 * @LastEditTime: 2023-11-22 13:27:07
 * @FilePath: \general-ai-platform-web\src\pages\Resource\BusinessImageList\components\UpdateForm.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
import { postProjectGetProjectFkSelect } from '@/services/project/Project';
import { putBusinessImageUpdateBusinessImage } from '@/services/resource/BusinessImage';
import {
  ModalForm,
  ProForm,
  ProFormDateTimePicker,
  ProFormSelect,
  ProFormText,
} from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form, message } from 'antd';
import React from 'react';
import { proFormItemStyleProps, proFormModelWidth } from '../../../../../config/defaultForm';
export type FormValueType = {
  target?: string;
  template?: string;
  type?: string;
  time?: string;
  frequency?: string;
} & Partial<API.BusinessImage>;

export type UpdateFormProps = {
  updateModalOpen: boolean;
  handleModal: () => void;
  values: Partial<API.BusinessImage>;
  reload: any;
};
const UpdateForm: React.FC<UpdateFormProps> = (props) => {
  const intl = useIntl();
  const [form] = Form.useForm<API.BusinessImage>();

  return (
    <ModalForm<API.BusinessImage>
      width={proFormModelWidth}
      title={intl.formatMessage({
        id: 'resource.business_image.table.list.update',
        defaultMessage: '$$$',
      })}
      open={props.updateModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => props.handleModal(),
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        putBusinessImageUpdateBusinessImage(values)
          .then(() => {
            message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
            props.reload();
          })
          .catch(() => {
            message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
          });

        props.handleModal();
        return true;
      }}
    >
      <ProForm.Group>
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="id"
          label="id"
          disabled={true}
          initialValue={props.values.id}
        />
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="name"
          label={
            <FormattedMessage id="resource.business_image.table.list.name" defaultMessage="$$$" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.name',
            defaultMessage: '$$$',
          })}`}
          required={true}
          initialValue={props.values.name}
          disabled={false}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="resource.business_image.table.rule.required.name"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="version"
          label={
            <FormattedMessage
              id="resource.business_image.table.list.version"
              defaultMessage="$$$"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.version',
            defaultMessage: '$$$',
          })}`}
          required={true}
          initialValue={props.values.version}
          disabled={false}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="resource.business_image.table.rule.required.version"
                  defaultMessage="version is required"
                />
              ),
            },
          ]}
        />
        <ProFormSelect
          width={proFormItemStyleProps.column2Width}
          name="projectFkId"
          label={
            <FormattedMessage
              id="resource.business_image.table.list.projectFkId"
              defaultMessage="$$$"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_select',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.projectFkId',
            defaultMessage: '$$$',
          })}`}
          required={true}
          initialValue={props.values.projectFkId}
          showSearch
          debounceTime={1000}
          request={async (keyWord) => {
            const resp = await postProjectGetProjectFkSelect({ keyword: keyWord?.keyWords || '' });
            return resp.data.list.map((v: any) => {
              return {
                label: v.name,
                value: v.id,
              };
            });
          }}
        />
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="path"
          label={
            <FormattedMessage id="resource.business_image.table.list.path" defaultMessage="$$$" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.path',
            defaultMessage: '$$$',
          })}`}
          required={false}
          initialValue={props.values.path}
          disabled={false}
        />
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="startCode"
          label={
            <FormattedMessage
              id="resource.business_image.table.list.startCode"
              defaultMessage="$$$"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.startCode',
            defaultMessage: '$$$',
          })}`}
          required={false}
          initialValue={props.values.startCode}
          disabled={false}
        />
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="configHash"
          label={
            <FormattedMessage
              id="resource.business_image.table.list.configHash"
              defaultMessage="$$$"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.configHash',
            defaultMessage: '$$$',
          })}`}
          required={false}
          initialValue={props.values.configHash}
          disabled={false}
        />
        <ProFormText
          width={proFormItemStyleProps.column2Width}
          name="remark"
          label={
            <FormattedMessage id="resource.business_image.table.list.remark" defaultMessage="$$$" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.remark',
            defaultMessage: '$$$',
          })}`}
          required={false}
          initialValue={props.values.remark}
          disabled={false}
        />
        <ProFormDateTimePicker
          width={proFormItemStyleProps.column2Width}
          name="createTime"
          label={
            <FormattedMessage
              id="resource.business_image.table.list.createTime"
              defaultMessage="$$$"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.createTime',
            defaultMessage: '$$$',
          })}`}
          required={false}
          initialValue={props.values.createTime}
          disabled={true}
        />
        <ProFormDateTimePicker
          width={proFormItemStyleProps.column2Width}
          name="updateTime"
          label={
            <FormattedMessage
              id="resource.business_image.table.list.updateTime"
              defaultMessage="$$$"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'resource.business_image.table.list.updateTime',
            defaultMessage: '$$$',
          })}`}
          required={false}
          initialValue={props.values.updateTime}
          disabled={true}
        />
      </ProForm.Group>
    </ModalForm>
  );
};
export default UpdateForm;
