import IsBatchDelete from '@/components/BatchOperation/isBatchDelete';
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import { ColumnDrawer as ProjectColumnDrawer } from '@/pages/Project/ProjectList/components/ColumnDrawer';
import { ProjectColumns } from '@/pages/Project/ProjectList/components/Columns';
import {
  postProjectGetProjectById,
  postProjectGetProjectFkSelect,
  postProjectGetProjectNames,
} from '@/services/project/Project';
import {
  deleteBusinessImageDeleteBusinessImage,
  postBusinessImageGetBusinessImageList,
} from '@/services/resource/BusinessImage';
import { PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { PageContainer, ProFormSelect, ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess, useIntl } from '@umijs/max';
import { Button, message } from 'antd';
import React, { useRef, useState } from 'react';
import { proTableCommonOptions, proTablePaginationOptions } from '../../../../config/defaultTable';
import { ColumnDrawer } from './components/ColumnDrawer';
import CreateForm from './components/CreateForm';
import UpdateForm from './components/UpdateForm';
const BusinessImageList: React.FC = () => {
  /**
   * @en-US Pop-up window of new window
   * @zh-CN 新建窗口的弹窗
   *  */
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  const [showDetail, setShowDetail] = useState<boolean>(false);
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  const access = useAccess();
  const intl = useIntl();
  const actionRef = useRef<ActionType>();
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  const [currentRow, setCurrentRow] = useState<API.BusinessImage>();
  const [selectedRowsState, setSelectedRows] = useState<API.BusinessImage[]>([]);
  const [project_fk_id_open, set_project_fk_id_open] = useState(false);
  const [project_fk_id, set_project_fk_id] = useState<API.Project>();
  const [project_fk_id_column_open, set_project_fk_id_column_open] = useState(false);
  const [projectFkIdIds, setProjectFkIdIds] = useState([]);
  const [projectFkIdMap, setProjectFkIdMap] = useState<{ [key: number]: string }>({});
  const handle_project_fk_id = (id: any) => {
    if (project_fk_id_open) {
      set_project_fk_id(undefined);
      set_project_fk_id_open(false);
    } else {
      postProjectGetProjectById({ id: id }).then((resp) => {
        set_project_fk_id(resp.data.project);
        set_project_fk_id_open(true);
      });
    }
  };
  const handle_project_fk_id_column_open = () => {
    if (project_fk_id_column_open) {
      set_project_fk_id_column_open(false);
    } else {
      postProjectGetProjectNames({ ids: projectFkIdIds }).then((resp) => {
        let a: any = {};
        resp.data.list.forEach((v: any) => {
          if (v.id) {
            a[v.id] = v.name;
          }
        });
        setProjectFkIdMap(a);
      });
      set_project_fk_id_column_open(true);
    }
  };

  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setUpdateModalOpen(true);
    }
  };
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };
  const handleColumnDrawer = () => {
    if (showDetail) {
      setShowDetail(false);
      setCurrentRow(undefined);
    } else {
      setShowDetail(true);
    }
  };
  const handleDestroy = async (selectedRow: API.BusinessImage) => {
    deleteBusinessImageDeleteBusinessImage({ id: selectedRow.id })
      .then(() => {
        message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        actionRef.current?.reload();
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  };

  const columns: ProColumns<API.BusinessImage>[] = [
    {
      title: <FormattedMessage id="resource.business_image.table.list.name" defaultMessage="$$$" />,
      dataIndex: 'name',
      hideInSearch: true,
      key: 'fixedName',
      fixed: 'left',
    },
    {
      title: <FormattedMessage id="resource.business_image.table.list.id" defaultMessage="id" />,
      dataIndex: 'id',
      // fixed: 'left',
      sorter: true,
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },
    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.version" defaultMessage="$$$" />
      ),
      dataIndex: 'version',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage
          id="resource.business_image.table.list.projectFkId"
          defaultMessage="$$$"
        />
      ),
      dataIndex: 'projectFkId',
      hideInSearch: false,
      render: (text, record) => {
        if (project_fk_id_column_open) {
          return (
            <a
              onClick={() => {
                handle_project_fk_id(record.projectFkId);
              }}
            >
              {record?.projectFkId ? projectFkIdMap[record.projectFkId] : undefined}
            </a>
          );
        } else {
          return (
            <a
              onClick={() => {
                handle_project_fk_id(record.projectFkId);
              }}
            >
              {record.projectFkId}
            </a>
          );
        }
      },
      renderFormItem: () => {
        return (
          // value 和 onchange 会通过 form 自动注入。
          <ProFormSelect
            placeholder={`${intl.formatMessage({
              id: 'common.please_select',
              defaultMessage: '$$$',
            })}`}
            required={false}
            showSearch
            debounceTime={1000}
            request={async (keyWord) => {
              const resp = await postProjectGetProjectFkSelect({
                keyword: keyWord?.keyWords || '',
              });
              return resp.data.list.map((v: any) => {
                return {
                  label: v.name,
                  value: v.id,
                };
              });
            }}
          />
        );
      },
    },

    {
      title: <FormattedMessage id="resource.business_image.table.list.path" defaultMessage="$$$" />,
      dataIndex: 'path',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.startCode" defaultMessage="$$$" />
      ),
      dataIndex: 'startCode',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.config" defaultMessage="$$$" />
      ),
      dataIndex: 'config',
      hideInSearch: true,
      hideInTable: true,
      hideInDescriptions: true,
    },

    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.configHash" defaultMessage="$$$" />
      ),
      dataIndex: 'configHash',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.remark" defaultMessage="$$$" />
      ),
      dataIndex: 'remark',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.createTime" defaultMessage="$$$" />
      ),
      dataIndex: 'createTime',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: (
        <FormattedMessage id="resource.business_image.table.list.updateTime" defaultMessage="$$$" />
      ),
      dataIndex: 'updateTime',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
              key: 'update',
              renderDom: (
                <Button
                  key="update"
                  type="link"
                  size="small"
                  onClick={() => {
                    setUpdateModalOpen(true);
                    setCurrentRow(record);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.update" defaultMessage="Update" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <PageContainer>
      <ProTable<API.BusinessImage>
        headerTitle={intl.formatMessage({
          id: 'pages.searchTable.title',
          defaultMessage: '$$$',
        })}
        options={{ fullScreen: true, setting: true, density: true, reload: true }}
        actionRef={actionRef}
        rowKey="key"
        scroll={{
          x: proTableCommonOptions.scrollX,
        }}
        search={{
          labelWidth: proTableCommonOptions.searchLabelWidth,
        }}
        onDataSourceChange={(data) => {
          let ProjectFkIdIds: any = data.map((v) => {
            return v.projectFkId;
          });
          setProjectFkIdIds(ProjectFkIdIds);
        }}
        pagination={{
          ...proTablePaginationOptions,
          pageSize: currentPageSize,
          onChange: (page, pageSize) => setCurrentPageSize(pageSize),
        }}
        columnsState={{
          persistenceKey: 'business_image_list',
          persistenceType: 'localStorage',
        }}
        tableAlertOptionRender={() => {
          return (
            <>
              {selectedRowsState?.length > 0 && (
                <IsBatchDelete
                  deleteApi={() => {
                    // TODO 未对接批量删除接口
                  }}
                />
              )}
            </>
          );
        }}
        toolBarRender={() => [
          <Access
            accessible={access.canUpdate(history.location.pathname)}
            key={`${history.location.pathname}-add`}
          >
            <Button
              type="primary"
              key="project_fk_id_show"
              onClick={() => {
                handle_project_fk_id_column_open();
              }}
            >
              {project_fk_id_column_open ? (
                <FormattedMessage id="common.hide" defaultMessage="$$$" />
              ) : (
                <FormattedMessage id="common.show" defaultMessage="$$$" />
              )}
              <FormattedMessage
                id="resource.business_image.table.list.projectFkId"
                defaultMessage="$$$"
              />
            </Button>

            <Button
              type="primary"
              key="primary"
              onClick={() => {
                setCreateModalOpen(true);
              }}
            >
              <PlusOutlined /> <FormattedMessage id="pages.searchTable.new" defaultMessage="New" />
            </Button>
          </Access>,
        ]}
        request={async (params = {}, sort) => {
          const { current, ...rest } = params;
          const reqParams = {
            page: current,
            desc: false,
            orderKey: '',
            ...rest,
          };
          if (sort && Object.keys(sort).length) {
            reqParams.orderKey = Object.keys(sort)[0];
            let sort_select = sort[reqParams.orderKey];
            reqParams.desc = sort_select === 'descend';
          }
          let resp = await postBusinessImageGetBusinessImageList({ ...reqParams });
          return {
            data: resp.data.list.map((v: API.BusinessImage) => {
              return { ...v, key: v.id };
            }),
            success: resp.success,
            total: resp.data.total,
            current: resp.data.page,
            pageSize: resp.data.pageSize,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />
      <CreateForm
        createModalOpen={createModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={actionRef.current?.reload}
      />
      <UpdateForm
        updateModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleUpdateModal}
        reload={actionRef.current?.reload}
      />

      <ColumnDrawer
        handleDrawer={handleColumnDrawer}
        isShowDetail={showDetail}
        columns={columns}
        currentRow={currentRow}
      />
      <ProjectColumnDrawer
        handleDrawer={handle_project_fk_id}
        isShowDetail={project_fk_id_open}
        columns={ProjectColumns}
        currentRow={project_fk_id}
      />
    </PageContainer>
  );
};

export default BusinessImageList;
