import {ModalForm, ProForm, ProFormDigit, ProFormSwitch} from '@ant-design/pro-components';
import {ProFormText} from '@ant-design/pro-components';
import {ProFormSelect} from '@ant-design/pro-components';
import {FormattedMessage, useIntl} from '@umijs/max';
import React from 'react';
import {Form, message} from 'antd';
import {putDictionaryUpdateDictionary} from "@/services/system/Dictionary";

export type UpdateFormProps = {
  updateModalOpen: boolean;
  handleModal: () => void;
  values: Partial<API.Dictionary>;
  reload: any;
};
const UpdateForm: React.FC<UpdateFormProps> = (props) => {

  const intl = useIntl();
  const [form] = Form.useForm<API.Dictionary>();

  return (
    <ModalForm<API.Dictionary>
      title={intl.formatMessage({
        id: 'common.modal.table.update.title',
        defaultMessage: '$$$',
      })}
      open={props.updateModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => props.handleModal(),
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        putDictionaryUpdateDictionary(values).then(() => {
          message.success(intl.formatMessage({id: 'common.success', defaultMessage: '$$$'}))
          props.reload()
        }).catch(() => {
          message.error(intl.formatMessage({id: 'common.failure', defaultMessage: '$$$'}))
        })

        props.handleModal();
        return true;
      }}
    >

      <ProForm.Group>
        <ProFormText width="md" name="id" label="id" disabled={true} initialValue={props.values.id}/>

        <ProFormText width="md" name="name"
                     label={<FormattedMessage id="system.role.table.list.name" defaultMessage="$$$"/>}
                     placeholder={`${intl.formatMessage({id: 'common.please_input', defaultMessage: '$$$'})}${intl.formatMessage({id: 'system.role.table.list.name', defaultMessage: '$$$'})}`}
                     required={true}
                     initialValue={props.values.name}
                     rules={[
                       {
                         required: true,
                         message: (
                           <FormattedMessage
                             id="system.role.table.rule.required.name"
                             defaultMessage="name is required"
                           />
                         ),
                       },
                     ]}
        />
        <ProFormText width="md" name="code"
                     label={<FormattedMessage id="system.role.table.list.code" defaultMessage="$$$"/>}
                     placeholder={`${intl.formatMessage({id: 'common.please_input', defaultMessage: '$$$'})}${intl.formatMessage({id: 'system.role.table.list.code', defaultMessage: '$$$'})}`}
                     required={true}
                     initialValue={props.values.code}
                     rules={[
                       {
                         required: true,
                         message: (
                           <FormattedMessage
                             id="system.role.table.rule.required.code"
                             defaultMessage="code is required"
                           />
                         ),
                       },
                     ]}
        />
        <ProFormDigit width="md" fieldProps={{precision: 0}} name="sort"
                      label={<FormattedMessage id="system.role.table.list.sort" defaultMessage="$$$"/>}
                      placeholder={`${intl.formatMessage({id: 'common.please_input', defaultMessage: '$$$'})}${intl.formatMessage({id: 'system.role.table.list.sort', defaultMessage: '$$$'})}`}
                      initialValue={props.values.sort}
        />
      </ProForm.Group>
      <ProForm.Group>
        <ProFormText width="md" name="remark"
                     label={<FormattedMessage id="system.role.table.list.remark" defaultMessage="$$$"/>}
                     placeholder={`${intl.formatMessage({id: 'common.please_input', defaultMessage: '$$$'})}${intl.formatMessage({id: 'system.role.table.list.remark', defaultMessage: '$$$'})}`}
                     required={false}
                     initialValue={props.values.}
        />
        <ProFormSwitch width="md" name="status" initialValue={props.values.status}
                       label={<FormattedMessage id="system.role.table.list.status" defaultMessage="$$$"/>}
                       required={false}>

        </ProFormSwitch>
      </ProForm.Group>
    </ModalForm>)
}
export default UpdateForm;
