import { deleteUserDeleteUser, postUserGetUserList } from '@/services/system/User';
import { PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { PageContainer, ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess, useIntl } from '@umijs/max';
import { Button, message } from 'antd';
import React, { useEffect, useRef, useState } from 'react';
import { ColumnDrawer } from './components/ColumnDrawer';
import CreateForm from './components/CreateForm';
import UpdateForm from './components/UpdateForm';

import { postDepartmentGetDepartmentTree } from '@/services/system/Department';
import { RedoOutlined } from '@ant-design/icons';
import { Tree } from 'antd';
import type { DataNode } from 'antd/es/tree';
// 列表操作栏组件
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
// 批量删除
import IsBatchDelete from '@/components/BatchOperation/isBatchDelete';
import TreeAndTableList, { ProCardTypeProps } from '@/layouts/treeAndTableList';

const UserList: React.FC = () => {
  /**
   * @en-US Pop-up window of new window
   * @zh-CN 新建窗口的弹窗
   *  */
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  const [showDetail, setShowDetail] = useState<boolean>(false);
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  const access = useAccess();
  const intl = useIntl();
  const actionRef = useRef<ActionType>();
  const [currentRow, setCurrentRow] = useState<API.User>();
  const [selectedRowsState, setSelectedRows] = useState<API.User[]>([]);
  const [deptTreeData, setDeptTreeData] = React.useState<DataNode[]>([]);
  const [selectDepts, setSelectDepts] = React.useState<any[]>([]);
  const [hasInit, setHasInit] = useState<boolean>(false);

  useEffect(() => {
    postDepartmentGetDepartmentTree()
      .then((resp) => {
        setDeptTreeData(resp.data.tree);
        setHasInit(true);
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  }, []);
  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setUpdateModalOpen(true);
    }
  };
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };
  const handleColumnDrawer = () => {
    if (showDetail) {
      setShowDetail(false);
      setCurrentRow(undefined);
    } else {
      setShowDetail(true);
    }
  };
  const handleDestroy = async (selectedRow: API.User) => {
    deleteUserDeleteUser(selectedRow)
      .then(() => {
        message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        actionRef.current?.reload();
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  };

  const columns: ProColumns<API.User>[] = [
    {
      title: <FormattedMessage id="system.user.table.list.id" defaultMessage="id" />,
      dataIndex: 'id',
      sorter: true,
      // valueType: "digit",
      filters: true,
      onFilter: true,
      render: (dom, entity) => {
        return (
          <a
            style={{ color: '#155BD4' }}
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },

    {
      sorter: true,
      title: <FormattedMessage id="system.user.table.list.userName" defaultMessage="$$$" />,
      dataIndex: 'userName',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="system.user.table.list.nickName" defaultMessage="$$$" />,
      dataIndex: 'nickName',
      hideInSearch: true,
    },
    {
      title: <FormattedMessage id="system.user.table.list.avatarId" defaultMessage="$$$" />,
      dataIndex: 'avatarUrl',
      hideInSearch: true,
      renderText: (v) => {
        if (v) {
          return SERVER_HOST + v.replace(/\\/g, '/');
        } else {
          return '';
        }
      },
      // hideInTable: true,
      valueType: 'image',
    },
    {
      title: <FormattedMessage id="system.user.table.list.enable" defaultMessage="$$$" />,
      dataIndex: 'enable',
      valueEnum: {
        true: {
          text: <FormattedMessage id="common.open" defaultMessage="$$" />,
          status: 'Success',
        },
        false: {
          text: <FormattedMessage id="common.close" defaultMessage="$$" />,
          status: 'Error',
        },
      },
      filters: true,
      onFilter: true,
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
              key: 'update',
              renderDom: (
                <Button
                  key="update"
                  type="link"
                  size="small"
                  onClick={() => {
                    setUpdateModalOpen(true);
                    setCurrentRow(record);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.update" defaultMessage="Update" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
        // <Access accessible={access.canUpdate(history.location.pathname)} key={`${history.location.pathname}-add`}>
        //   <a
        //     key="update"
        //     onClick={() => {
        //       setUpdateModalOpen(true);
        //       setCurrentRow(record);
        //     }}
        //   >
        //     <FormattedMessage id="pages.searchTable.update" defaultMessage="Update"/>
        //   </a>
        //   <Popconfirm
        //     placement="topLeft"
        //     title={intl.formatMessage({ id: 'common.tip.title', defaultMessage: '$$$' })}
        //     description={intl.formatMessage({
        //       id: 'common.modal.table.delete.content',
        //       defaultMessage: '$$$',
        //     })}
        //     okText={intl.formatMessage({ id: 'common.yes', defaultMessage: '$$$' })}
        //     cancelText={intl.formatMessage({ id: 'common.no', defaultMessage: '$$$' })}
        //     onConfirm={() => {
        //       handleDestroy(record).then(() => {});
        //     }}
        //   >
        //     <Button key="destroy" type="link" size="small" danger>
        //     <FormattedMessage id="pages.searchTable.destroy" defaultMessage="Destroy" />
        //     </Button>
        //   </Popconfirm>
        // </Access>
      ],
    },
  ];
  return (
    <PageContainer>
      <TreeAndTableList
        leftCard={
          {
            title: '部门选择',
            extra: (
              <>
                <Button
                  icon={<RedoOutlined />}
                  onClick={() => {
                    setSelectDepts([]);
                    actionRef.current?.reload();
                  }}
                >
                  重置
                </Button>
              </>
            ),
          } as ProCardTypeProps
        }
        leftDom={
          hasInit && (
            <Tree
              checkable={false}
              defaultExpandAll={true}
              selectedKeys={selectDepts}
              treeData={deptTreeData}
              onSelect={(selectKeys) => {
                setSelectDepts(selectKeys);
                actionRef.current?.reload();
              }}
            />
          )
        }
        rightDom={
          <ProTable<API.User>
            headerTitle={intl.formatMessage({
              id: 'pages.searchTable.title',
              defaultMessage: '$$$',
            })}
            options={{ fullScreen: true, setting: true, density: true, reload: true }}
            actionRef={actionRef}
            rowKey="id"
            search={{
              labelWidth: 'auto',
            }}
            pagination={{
              showSizeChanger: true,
              pageSize: 10,
            }}
            columnsState={{
              persistenceKey: 'api_list',
              persistenceType: 'localStorage',
            }}
            toolBarRender={() => [
              <Access
                accessible={access.canUpdate(history.location.pathname)}
                key={`${history.location.pathname}-add`}
              >
                <Button
                  type="primary"
                  key="primary"
                  onClick={() => {
                    setCreateModalOpen(true);
                  }}
                >
                  <PlusOutlined />{' '}
                  <FormattedMessage id="pages.searchTable.new" defaultMessage="New" />
                </Button>
              </Access>,
            ]}
            request={async (params = {}, sort) => {
              const { current, ...rest } = params;
              const reqParams: any = {
                page: current,
                desc: false,
                orderKey: '',
                ...rest,
              };
              if (selectDepts.length) {
                reqParams.deptId = selectDepts[0];
              }
              if (sort && Object.keys(sort).length) {
                reqParams.orderKey = Object.keys(sort)[0];
                let sort_select = sort[reqParams.orderKey];
                reqParams.desc = sort_select === 'descend';
              }
              let resp = await postUserGetUserList({ ...reqParams });
              console.log(resp);
              return {
                data: resp.data.list,
                success: resp.success,
                total: resp.data.total,
                current: resp.data.page,
                pageSize: resp.data.pageSize,
              };
            }}
            columns={columns}
            rowSelection={{
              onChange: (_, selectedRows) => {
                setSelectedRows(selectedRows);
              },
            }}
            tableAlertOptionRender={() => {
              return (
                <>
                  {selectedRowsState?.length > 0 && (
                    <IsBatchDelete
                      deleteApi={() => {
                        const ids = selectedRowsState.map((v: API.User) => {
                          return v.id;
                        });
                        // deleteUserDeleteUsersByIds({ids: ids as number[]}).then(() => {
                        //   actionRef.current?.reloadAndRest?.();
                        // })
                      }}
                    />
                  )}
                </>
              );
            }}
          />
        }
      ></TreeAndTableList>

      <CreateForm
        createModalOpen={createModalOpen}
        values={(currentRow as API.Register) || {}}
        handleModal={handleCreateModal}
        reload={actionRef.current?.reload}
      />
      <UpdateForm
        updateModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleUpdateModal}
        reload={actionRef.current?.reload}
      />

      <ColumnDrawer
        handleDrawer={handleColumnDrawer}
        isShowDetail={showDetail}
        columns={columns}
        currentRow={currentRow}
      />
    </PageContainer>
  );
};

export default UserList;
